@@ -782,13 +782,3 @@ class VariableClHelpSet(ReadonlyVariable):
     """
     type = "bool"
     value = "off"
-
-class DataVarsConfig(SimpleDataVars):
-    """
-    Получить профиль и emerge config из chroot системы
-    """
-    def __init__(self, chroot_path='/'):
-        SimpleDataVars.__init__(
-            self,
-            VariableClMakeProfile(systemRoot=chroot_path),
-            VariableClEmergeConfig(systemRoot=chroot_path))
